import {Component, EventEmitter, Input, Output} from '@angular/core';
import {FormsModule} from "@angular/forms";
import {MatCardModule} from "@angular/material/card";
import {MatFormFieldModule} from "@angular/material/form-field";
import {MatInputModule} from "@angular/material/input";
import {MatSelectModule} from "@angular/material/select";
import {NgForOf, NgIf} from "@angular/common";
import {Ingredient} from "../../../Models/ingredient";
import {Unit} from "../../../Models/unit";
import {MatButtonModule} from "@angular/material/button";
import {MatIconModule} from "@angular/material/icon";

@Component({
  selector: 'app-ingredient-item',
  standalone: true,
  imports: [
    FormsModule,
    MatCardModule,
    MatFormFieldModule,
    MatInputModule,
    MatSelectModule,
    NgForOf,
    NgIf,
    MatButtonModule,
    MatIconModule
  ],
  templateUrl: './ingredient-item.component.html',
  styleUrl: './ingredient-item.component.css'
})
export class IngredientItemComponent {
  //Todo make output callback to get filter values
  @Input() ingredient?: Ingredient; // Use optional chaining
  @Input() unitOptions?: Unit[];

  @Output() amountChange = new EventEmitter<number>();
  @Output() unitChange = new EventEmitter<Unit>();
  @Output() removeIngredient = new EventEmitter<Ingredient>();

  onAmountChange(): void {
    if (this.ingredient?.amount !== null && this.ingredient?.amount !== undefined) {
      this.amountChange.emit(this.ingredient.amount);
      console.log("Amount changed to: " + this.ingredient.amount)
    }
  }

  onUnitChange(): void {
    if (this.ingredient?.selectedUnit) {
      this.unitChange.emit(this.ingredient.selectedUnit);
      console.log("Unit changed to: " + this.ingredient.selectedUnit)
    }
  }
}
