import {Component, Input, OnInit} from '@angular/core';
import {Recipe} from "../../../Models/recipe";
import {NgForOf, NgIf} from "@angular/common";
import {MatIconModule} from "@angular/material/icon";
import {VisualisationService} from '../../../Services/visualisation.service';
import {RecipeDataService} from '../../../Services/recipe-data.service';
import {Ingredient, IngredientDto} from "../../../Models/ingredient";
import {IngredientDataService} from "../../../Services/ingredient-data.service";
import {FilterService} from "../../../Services/filter.service";

@Component({
  selector: 'app-recipe-preview',
  standalone: true,
  imports: [
    NgIf,
    NgForOf,
    MatIconModule
  ],
  templateUrl: './recipe-preview.component.html',
  styleUrl: './recipe-preview.component.css'
})
export class RecipePreviewComponent implements OnInit {

  recipeID: number = 0;

  //@Input() recipe?: Recipe;
  recipe: Recipe | undefined;
  ingredients: Ingredient[] = []
  selectedIngredients: Ingredient[] = []

  constructor(private recipeDataService: RecipeDataService,
              private visualizationService: VisualisationService,
              private ingredientService: IngredientDataService,
              private filterService: FilterService) {
  }

  ngOnInit() {
    console.log(this.visualizationService.selectedRecipe$);
    this.visualizationService.selectedRecipe$.subscribe(recipeID => {
      this.recipeID = recipeID;
      this.recipeDataService.recipes$.subscribe((result) => {
        this.recipe = result[this.recipeID];
      });
    });
    this.ingredientService.ingredients$.subscribe(data => this.ingredients = data)
    this.filterService.selectedIngredients$.subscribe(data => this.selectedIngredients = data)
  }

  getStarRating(): number {
    if (!this.recipe) return -1;
    return Math.round(this.recipe.rating * 2) / 2;

  }

  getIngredientsAmount(amount: any, unit: string) {
    if (unit == "unknown") {
      if (amount == "unknown") {
        return "some"

      }
      return Math.round(amount * 100) / 100
    }
    if (amount == "unknown") {
      return "some " + unit
    }
    return Math.round(amount * 100) / 100 + " " + unit
  }

  getIngredientsTitle(ids: number[]) {
    const ingredientTitles = ids.map(id => this.ingredients[id].title);
    // Combine the titles into a single string
    const combinedTitle = ingredientTitles.join(' ');

    return combinedTitle;
  }

  getIngredientTitle(id: number) {
    return this.ingredients[id].title;
  }

  protected readonly console = console;

  isSelected(id: number) {

    return this.selectedIngredients.some(selected => selected.id === id);
  }
}
