import { Component } from '@angular/core';
import {MatInputModule} from "@angular/material/input";
import {MatSelectModule} from "@angular/material/select";
import {FormsModule} from "@angular/forms";
import {AxisOptions} from "../../../Models/axis-options";
import {VisualisationService} from "../../../Services/visualisation.service";
import {NgForOf} from "@angular/common";

@Component({
  selector: 'app-vis-controller',
  standalone: true,
  imports: [
    MatInputModule,
    MatSelectModule,
    FormsModule,
    NgForOf
  ],
  templateUrl: './vis-controller.component.html',
  styleUrl: './vis-controller.component.css'
})
export class VisControllerComponent {
  visualizationOptions = Object.values(AxisOptions);
  selectedXAxis: AxisOptions = AxisOptions.Option1;
  selectedYAxis: AxisOptions = AxisOptions.Option2;
  selectedColorAxis: AxisOptions = AxisOptions.Option0; // Change as needed

  previousXAxis = this.selectedXAxis;
  previousYAxis = this.selectedYAxis;
  previousColorAxis = this.selectedColorAxis;

  constructor(private visualizationService: VisualisationService) {}

  onAxisChange(xAxis: AxisOptions, yAxis: AxisOptions, cAxis: AxisOptions): void {
    if (xAxis === yAxis) {
      // Swap the axes to maintain different selections
      [this.selectedXAxis, this.selectedYAxis] = [this.previousYAxis, this.previousXAxis];
    }
    if (xAxis === cAxis) {
      [this.selectedXAxis, this.selectedColorAxis] = [this.previousColorAxis, this.previousXAxis];
    }
    if (yAxis === cAxis) {
      [this.selectedYAxis, this.selectedColorAxis] = [this.previousColorAxis, this.previousYAxis];
    }
    this.previousXAxis = this.selectedXAxis;
    this.previousYAxis = this.selectedYAxis;
    this.previousColorAxis = this.selectedColorAxis;

    this.visualizationService.setSelectedAxes(this.selectedXAxis, this.selectedYAxis, this.selectedColorAxis);
  }
}
