import { Injectable } from '@angular/core';
import {BehaviorSubject, catchError, map, Observable} from "rxjs";
import {Ingredient} from "../Models/ingredient";
import {HttpClient} from "@angular/common/http";
import {Recipe} from "../Models/recipe";

@Injectable({
  providedIn: 'root'
})
export class IngredientDataService {
  private ingredientsUrl = 'assets/ingredients.json';

  private ingredientsDataSubject = new BehaviorSubject<Ingredient[]>([]);

  ingredients$ = this.ingredientsDataSubject.asObservable();
  constructor(private http: HttpClient) { }

  getIngredients(): Observable<Ingredient[]> {
    return this.http.get<Ingredient[]>(this.ingredientsUrl)
      .pipe(

        map(data =>{
          const ingredients = this.mapToIngredients(data);
          this.ingredientsDataSubject.next(ingredients); // Update the BehaviorSubject
          return ingredients;
        }),
        catchError(this.handleError)
      );
  }
  private mapToIngredients(data: any): Ingredient[] {
    const ingredients: Ingredient[] = [];

    // Map the numeric keys to an array of ingredients
    Object.keys(data).forEach(key => {
      const ingredientData = data[key];
      const ingredient: Ingredient = {
        id: +key, // Convert the key to a number
        title: ingredientData.name || 'Unknown', // Use a default value if 'name' is not present
        amount: 0, // You can adjust the default value for 'amount' as needed
        units: [], // You can adjust the default value for 'units' as needed
        selectedUnit: undefined,
      };

      ingredients.push(ingredient);
    });

    return ingredients;
  }
  private handleError(error: any): Observable<never> {
    console.error('An error occurred', error);
    return new Observable<never>();
  }
}
