import { Injectable } from '@angular/core';
import {HttpClient} from "@angular/common/http";
import {catchError, map, Observable} from "rxjs";
import {Ingredient} from "../Models/ingredient";
import {Unit} from "../Models/unit";

@Injectable({
  providedIn: 'root'
})
export class UnitDataService {
  private ingredientsUrl = 'assets/units.json';
  constructor(private http: HttpClient) { }

  getUnits(): Observable<Unit[]> {
    return this.http.get<Unit[]>(this.ingredientsUrl)
      .pipe(
        map(data => this.mapToUnits(data)),
        catchError(this.handleError)
      );
  }
  //TODO adjust for data model changes
  private mapToUnits(data: any): Unit[] {
    const ingredients: Unit[] = [];
    const uniqueUnitsSet = new Set<string>();

    Object.values(data).forEach(value => uniqueUnitsSet.add(<string>value));

    const uniqueUnitsArray: Unit[] = Array.from(uniqueUnitsSet).map(title => ({ title }));

    uniqueUnitsArray.sort((a, b) => a.title.localeCompare(b.title));

    return uniqueUnitsArray;
  }
  private handleError(error: any): Observable<never> {
    console.error('An error occurred', error);
    return new Observable<never>();
  }
}
