import { Injectable } from '@angular/core';
import {AxisOptions} from "../Models/axis-options";
import {BehaviorSubject} from "rxjs";
import { Modes } from '../Components/UI/mode-select/modes';

@Injectable({
  providedIn: 'root'
})
export class VisualisationService {
  private selectedAxesSubject = new BehaviorSubject<{ xAxis: AxisOptions; yAxis: AxisOptions, colorAxis: AxisOptions }>({
    xAxis: AxisOptions.Option1,
    yAxis: AxisOptions.Option2,
    colorAxis: AxisOptions.Option0
  });
  private selectedRecipeSubject = new BehaviorSubject<number>(0);
  private selectedModeSubject = new BehaviorSubject<Modes>(Modes.EXPLORE);

  selectedAxes$ = this.selectedAxesSubject.asObservable();
  selectedRecipe$ = this.selectedRecipeSubject.asObservable();
  selectedMode$ = this.selectedModeSubject.asObservable();

  setSelectedAxes(xAxis: AxisOptions, yAxis: AxisOptions, colorAxis: AxisOptions): void {
    this.selectedAxesSubject.next({xAxis, yAxis, colorAxis});
  }
  setSelectedRecipe(id: number): void {
    this.selectedRecipeSubject.next(id);
  }
  setSelectedMode(mode: Modes): void {
    this.selectedModeSubject.next(mode);
  }
}
