export const limits_computes_shader = /* wgsl */ `

struct Uniforms {
  resolution: vec2f,
  selected_index: u32,
  selected_mode: u32,
};

struct Limits {
  rating_min: atomic<u32>,
  rating_max: atomic<u32>,
  complexity_min: atomic<u32>,
  complexity_max: atomic<u32>,
  ingredient_count_min: atomic<u32>,
  ingredient_count_max: atomic<u32>,
}


@group(0) @binding(0) var<uniform> uniforms: Uniforms;
@group(0) @binding(1) var<storage, read> rating: array<f32>;
@group(0) @binding(2) var<storage, read> complexity: array<f32>;
@group(0) @binding(3) var<storage, read> ingredients_count: array<u32>;
@group(0) @binding(4) var<storage, read> ingredient_ids: array<u32>;
@group(0) @binding(5) var<storage, read> filter_ingredient_ids: array<u32>;
@group(0) @binding(6) var<storage, read_write> limits: Limits;


fn test_recipe(id: u32, explore_mode: bool) -> bool {
  var found_ingredients = array<bool, 20>();

  for (var i:u32=0u; i<20u; i++ ) {
    var ingredient_part_01:u32 = ingredient_ids[id*20*3 + i*3 + 0];
    var ingredient_part_23:u32 = ingredient_ids[id*20*3 + i*3 + 1];
    var ingredient_part_45:u32 = ingredient_ids[id*20*3 + i*3 + 2];

    var ingredient_0:u32 = ingredient_part_01 >> 16u;
    var ingredient_1:u32 = ingredient_part_01 & 0xff;
    var ingredient_2:u32 = ingredient_part_23 >> 16u;
    var ingredient_3:u32 = ingredient_part_23 & 0xff;
    var ingredient_4:u32 = ingredient_part_45 >> 16u;
    var ingredient_5:u32 = ingredient_part_45 & 0xff;

    for (var j:u32=0u; j<20u; j++ ) {
      var filter_ingredient = filter_ingredient_ids[j];

      if (filter_ingredient == 0) {
        continue;
      }

      if (ingredient_0 == filter_ingredient || 
          ingredient_1 == filter_ingredient || 
          ingredient_2 == filter_ingredient || 
          ingredient_3 == filter_ingredient || 
          ingredient_4 == filter_ingredient || 
          ingredient_5 == filter_ingredient) {
            
          found_ingredients[j] = true;
      }
    }
  }


  for (var i:u32=0u; i<20u; i++ ) {
    if (filter_ingredient_ids[i] == 0) {
      continue;
    }
    if (explore_mode && found_ingredients[i]) {
      return true;
    } else if(!explore_mode && !found_ingredients[i]) {
      return false;
    }
  }

  return !explore_mode;
}

@compute @workgroup_size(64)
fn compute(@builtin(global_invocation_id) globalId: vec3u) {
  if (globalId.x >= arrayLength(&rating)) {
      return;
  }

  let recipeIndex = globalId.x;

  var tmp1 = uniforms.selected_mode;
  var tmp2 = ingredient_ids[0];
  var tmp3 = filter_ingredient_ids[0];

  if (test_recipe(recipeIndex, uniforms.selected_mode == 0)) {
    atomicMin(&limits.rating_min, u32(rating[recipeIndex] * 1000.0));
    atomicMax(&limits.rating_max, u32(rating[recipeIndex] * 1000.0));
    atomicMin(&limits.complexity_min, u32(complexity[recipeIndex] * 1000.0));
    atomicMax(&limits.complexity_max, u32(complexity[recipeIndex] * 1000.0));
    atomicMin(&limits.ingredient_count_min, ingredients_count[recipeIndex] * 1000);
    atomicMax(&limits.ingredient_count_max, ingredients_count[recipeIndex] * 1000);
  }
}

`